"use strict";(self.webpackChunkjupyter_matplotlib=self.webpackChunkjupyter_matplotlib||[]).push([[480],{480:(e,t,i)=>{i.r(t),i.d(t,{default:()=>s});var l=i(395),n=i(657);const s={id:"matplotlib-jupyter:main",requires:[l.IJupyterWidgetRegistry],activate:function(e,t){t.registerWidget({name:n.o,version:n.Y,exports:()=>i.e(643).then(i.bind(i,688))})},autoStart:!0}},657:(e,t,i)=>{i.d(t,{Y:()=>n,o:()=>s});const l=i(147),n=l.version,s=l.name},147:e=>{e.exports=JSON.parse('{"name":"jupyter-matplotlib","version":"0.12.0","description":"Matplotlib Jupyter Interactive Widget","author":"Matplotlib Development team","license":"BSD-3-Clause","main":"lib/index.js","types":"./lib/index.d.ts","files":["lib/**/*.js","dist/*.js","css/*.css"],"repository":{"type":"git","url":"https://github.com/matplotlib/jupyter-matplotlib.git"},"scripts":{"build":"jlpm build:lib && jlpm build:nbextension && jlpm build:labextension:dev","build:prod":"jlpm build:lib && jlpm build:nbextension && jlpm build:labextension","build:labextension":"jupyter labextension build .","build:labextension:dev":"jupyter labextension build --development True .","build:lib":"tsc","build:nbextension":"webpack --mode=production","clean":"jlpm clean:lib && jlpm clean:nbextension && jlpm clean:labextension","clean:lib":"rimraf lib","clean:labextension":"rimraf ipympl/labextension","clean:nbextension":"rimraf ipympl/nbextension/static/index.js","prepack":"jlpm build:lib","test":"jest","watch":"npm-run-all -p watch:*","watch:lib":"tsc -w","watch:nbextension":"webpack --watch --mode=development","watch:labextension":"jupyter labextension watch .","eslint":"eslint . --fix --ignore-path .eslintignore --ext .ts","eslint:check":"eslint . --ignore-path .eslintignore --ext .ts","lint":"jlpm prettier && jlpm eslint","lint:check":"jlpm prettier:check && jlpm eslint:check","prepublish":"jlpm clean && jlpm build","prettier":"prettier --ignore-path .eslintignore --write \\"**/*{.ts,.css,.json}\\"","prettier:check":"prettier --check --ignore-path .eslintignore \\"**/*{.ts,.css,.json}\\""},"jupyterlab":{"extension":"lib/plugin","outputDir":"ipympl/labextension/","sharedPackages":{"@jupyter-widgets/base":{"bundled":false,"singleton":true}}},"devDependencies":{"@babel/core":"^7.5.0","@babel/preset-env":"^7.5.0","@jupyterlab/builder":"^4.0.0","@jupyterlab/testutils":"^4.0.0","@phosphor/application":"^1.6.0","@phosphor/widgets":"^1.6.0","@types/jest":"^29.2.0","@types/json-schema":"^7.0.11","@types/lodash":"^4.14.202","@types/react":"^18.0.26","@types/react-addons-linked-state-mixin":"^0.14.22","@types/webpack-env":"^1.13.6","@typescript-eslint/eslint-plugin":"^6.1.0","@typescript-eslint/parser":"^6.1.0","acorn":"^7.2.0","css-loader":"^6.7.1","eslint":"^8.36.0","eslint-config-prettier":"^8.8.0","eslint-plugin-prettier":"^5.0.0","fs-extra":"^7.0.0","identity-obj-proxy":"^3.0.0","jest":"^29.2.0","mkdirp":"^0.5.1","npm-run-all":"^4.1.5","prettier":"^3.0.0","rimraf":"^5.0.1","source-map-loader":"^1.0.2","style-loader":"^3.3.1","stylelint":"^15.10.1","stylelint-config-recommended":"^13.0.0","stylelint-config-standard":"^34.0.0","stylelint-csstree-validator":"^3.0.0","stylelint-prettier":"^4.0.0","ts-jest":"^29.0.0","ts-loader":"^8.0.0","typescript":"~5.3.3","webpack":"^5.61.0","webpack-cli":"^4.0.0","yjs":"^13.5.40"},"dependencies":{"@jupyter-widgets/base":"^2 || ^3 || ^4 || ^5 || ^6","@types/node":"^14.14.35","crypto":"1.0.1","lodash":"^4.17.21"},"keywords":["jupyter","jupyterlab","jupyterlab-extension","widgets"]}')}}]);